lnurl
=====

Based on https://github.com/rustyrussell/lightning-payencode (via https://github.com/fiatjaf/bech32)

Usage
-----

```
import lnurl

lnurl.encode('https://example.com/c?p=a8dw93x2h39s1f')

lnurl.decode('LNURL1DP68GURN8GHJ7ETCV9KHQMR99E3K7MF0VVLHQ0TP8PJ8WWFN0QEXSVEEWVCKVF3A4RP')
```
